pub struct ResponseCondition {
pub condition_type: ResponseConditionType,
pub status_code: Option<StatusCodeMatcher>,
pub raw_body: Option<BodyMatcher>,
pub body: Option<BTreeMap<String, BodyMatcher>>,
}Expand description
A response condition that determines if a secret is valid or invalid
Fields
condition_type: ResponseConditionTypeWhether this condition indicates a valid or invalid secret
status_code: Option<StatusCodeMatcher>Optional status code matcher
raw_body: Option<BodyMatcher>Optional raw body matcher (before parsing)
body: Option<BTreeMap<String, BodyMatcher>>Optional parsed body matchers (after JSON parsing) Maps JSON paths to matchers Example: {“message.stack[2].success.status”: BodyMatcher}
Implementations
Sourceimpl ResponseCondition
impl ResponseCondition
Sourcepub fn matches(&self, status_code: u16, body: &str) -> ResponseConditionResult
pub fn matches(&self, status_code: u16, body: &str) -> ResponseConditionResult
Determines if a ResponseCondition matches a given status code and body It does this by checking against each of the optional conditions and aggregating the results.
Consider the example of a ResponseCondition with the following conditions:
- status_code: 200
- raw_body: “success”
If the status code is 200, the raw body is “success”, ResponseCondition matches. If the status code is 200, the raw body is “failure”, then the ResponseCondition does not match.
What happens next depends on the ResponseConditionType and whether or not the condition matched:
- Matched and Invalid -> Invalid
- Matched and Valid -> Valid
- Not matched -> NotChecked